#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src
version:              1.0.4.2
visibility:           public
id:                   haskell-src-1.0.4.2-3asFHa10YQUG94oeGrKMbp
key:                  haskell-src-1.0.4.2-3asFHa10YQUG94oeGrKMbp
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Simon Marlow, Sven Panne and Noel Winstanley
stability:            stable
synopsis:             Support for manipulating Haskell source code
description:
    The @haskell-src@ package provides support for manipulating Haskell
    source code. The package provides a lexer, parser and
    pretty-printer, and a definition of a Haskell abstract syntax tree
    (AST). Common uses of this package are to parse or generate
    <http://www.haskell.org/onlinereport/ Haskell 98> code.

category:             Language
abi:                  b540ad9528575a914c0824c0210e51f6
exposed:              True
exposed-modules:
    Language.Haskell.Lexer Language.Haskell.ParseMonad
    Language.Haskell.ParseUtils Language.Haskell.Parser
    Language.Haskell.Pretty Language.Haskell.Syntax

import-dirs:          /usr/lib/ghc-9.6.6/site-local/haskell-src-1.0.4.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/haskell-src-1.0.4.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/haskell-src-1.0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src
hs-libraries:         HShaskell-src-1.0.4.2-3asFHa10YQUG94oeGrKMbp
depends:
    array-0.5.6.0 base-4.18.2.1 pretty-1.1.3.6
    syb-0.7.3-LuAboeaVABfIZpaDvWE0xD

haddock-interfaces:   /usr/share/doc/haskell-src/html/haskell-src.haddock
haddock-html:         /usr/share/doc/haskell-src/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

